summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codegenerators/rubycodeclassfielddeclarationblock.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/codegenerators/rubycodeclassfielddeclarationblock.cpp')
-rw-r--r--umbrello/umbrello/codegenerators/rubycodeclassfielddeclarationblock.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/umbrello/umbrello/codegenerators/rubycodeclassfielddeclarationblock.cpp b/umbrello/umbrello/codegenerators/rubycodeclassfielddeclarationblock.cpp
index da8eb00e..e99ca774 100644
--- a/umbrello/umbrello/codegenerators/rubycodeclassfielddeclarationblock.cpp
+++ b/umbrello/umbrello/codegenerators/rubycodeclassfielddeclarationblock.cpp
@@ -22,8 +22,8 @@
// Constructors/Destructors
//
-RubyCodeClassFieldDeclarationBlock::RubyCodeClassFieldDeclarationBlock ( CodeClassField * tqparent )
- : CodeClassFieldDeclarationBlock ( tqparent )
+RubyCodeClassFieldDeclarationBlock::RubyCodeClassFieldDeclarationBlock ( CodeClassField * parent )
+ : CodeClassFieldDeclarationBlock ( parent )
{
setOverallIndentationLevel(1);
updateContent();
@@ -71,7 +71,7 @@ void RubyCodeClassFieldDeclarationBlock::updateContent( )
break;
default:
case CodeGenerationPolicy::FromParent:
// do nothing here... will leave as from tqparent object
break;
}
}
@@ -95,7 +95,7 @@ void RubyCodeClassFieldDeclarationBlock::updateContent( )
} else {
// FIX?: IF a constructor method exists in the classifiercodedoc
// of the tqparent Object, then we can use that instead (if its empty).
if(cf->fieldIsSingleValue())
{
if(!typeName.isEmpty())
@@ -71,7 +71,7 @@ void RubyCodeClassFieldDeclarationBlock::updateContent( )
default:
case CodeGenerationPolicy::FromParent:
- // do nothing here... will leave as from tqparent object
+ // do nothing here... will leave as from parent object
break;
}
@@ -95,7 +95,7 @@ void RubyCodeClassFieldDeclarationBlock::updateContent( )
} else {
// FIX?: IF a constructor method exists in the classifiercodedoc
- // of the tqparent Object, then we can use that instead (if its empty).
+ // of the parent Object, then we can use that instead (if its empty).
if(cf->fieldIsSingleValue())
{